/*
 * Fortanix SDKMS REST API
 *
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations.
 *
 * API version: 1.0.0-20180820
 * Contact: support@fortanix.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package sdkms

import (
	"net/http"
	"testing"

	"golang.org/x/net/context"
)

func TestApprovalRequestsApiService_Approve(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx       context.Context
		requestId string
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name            string
		fields          fields
		args            args
		want            *http.Response
		wantCheckFields []string //Name of fields from json object *http.Response to be verified.
		wantCheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr         bool
	}{
	// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &ApprovalRequestsApiService{
				client: tt.fields.client,
			}
			got, err := a.Approve(tt.args.ctx, tt.args.requestId)
			if (err != nil) != tt.wantErr {
				t.Errorf("ApprovalRequestsApiService.Approve() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("ApprovalRequestsApiService.Approve() = %v, want %v", got, tt.want)
			}
		})
	}
}

func TestApprovalRequestsApiService_CreateApprovalRequest(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body ApprovalRequestRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	/* TODO
	 * Create a new group, policy, app and security object for quorum approval testing
	 * Use key id of newly created security object
	*/ 
	key := SobjectDescriptor{
		Kid: "cbc9e64b-721f-4c64-8a4d-62e906e0ef43",
	}

	objType := ObjectType_AES
	mode := CryptMode_CBC

	encrypt_request := &EncryptRequestEx{
		Alg: &objType,
		Plain: "abcd",
		Mode: &mode,
		Key: &key,
	}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             ApprovalRequest
		wantCheckFields  []string //Name of fields from json object ApprovalRequest to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
	// Create approval request negative test.
		{
			name: "Create Approval Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: ApprovalRequestRequest{
					Operation: "/crypto/v1/encrypt",
					Method: "POST",
					Body: &encrypt_request,
					Description: "Description",
				},
			},
			wantErr: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &ApprovalRequestsApiService{
				client: tt.fields.client,
			}

			got, got1, err := a.CreateApprovalRequest(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("ApprovalRequestsApiService.CreateApprovalRequest() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("ApprovalRequestsApiService.CreateApprovalRequest() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("ApprovalRequestsApiService.CreateApprovalRequest() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestApprovalRequestsApiService_DeleteApprovalRequest(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx       context.Context
		requestId string
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name            string
		fields          fields
		args            args
		want            *http.Response
		wantCheckFields []string //Name of fields from json object *http.Response to be verified.
		wantCheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr         bool
	}{
	// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &ApprovalRequestsApiService{
				client: tt.fields.client,
			}
			got, err := a.DeleteApprovalRequest(tt.args.ctx, tt.args.requestId)
			if (err != nil) != tt.wantErr {
				t.Errorf("ApprovalRequestsApiService.DeleteApprovalRequest() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("ApprovalRequestsApiService.DeleteApprovalRequest() = %v, want %v", got, tt.want)
			}
		})
	}
}

func TestApprovalRequestsApiService_Deny(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx       context.Context
		requestId string
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name            string
		fields          fields
		args            args
		want            *http.Response
		wantCheckFields []string //Name of fields from json object *http.Response to be verified.
		wantCheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr         bool
	}{
	// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &ApprovalRequestsApiService{
				client: tt.fields.client,
			}
			got, err := a.Deny(tt.args.ctx, tt.args.requestId)
			if (err != nil) != tt.wantErr {
				t.Errorf("ApprovalRequestsApiService.Deny() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("ApprovalRequestsApiService.Deny() = %v, want %v", got, tt.want)
			}
		})
	}
}

func TestApprovalRequestsApiService_GetApprovalRequest(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx       context.Context
		requestId string
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             ApprovalRequest
		wantCheckFields  []string //Name of fields from json object ApprovalRequest to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
	// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &ApprovalRequestsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.GetApprovalRequest(tt.args.ctx, tt.args.requestId)
			if (err != nil) != tt.wantErr {
				t.Errorf("ApprovalRequestsApiService.GetApprovalRequest() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("ApprovalRequestsApiService.GetApprovalRequest() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("ApprovalRequestsApiService.GetApprovalRequest() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestApprovalRequestsApiService_GetApprovalRequests(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx               context.Context
		localVarOptionals map[string]interface{}
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             []ApprovalRequest
		wantCheckFields  []string //Name of fields from json object []ApprovalRequest to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
	// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &ApprovalRequestsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.GetApprovalRequests(tt.args.ctx, tt.args.localVarOptionals)
			if (err != nil) != tt.wantErr {
				t.Errorf("ApprovalRequestsApiService.GetApprovalRequests() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("ApprovalRequestsApiService.GetApprovalRequests() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("ApprovalRequestsApiService.GetApprovalRequests() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestApprovalRequestsApiService_GetResult(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx       context.Context
		requestId string
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             ApprovableResult
		wantCheckFields  []string //Name of fields from json object ApprovableResult to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
	// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &ApprovalRequestsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.GetResult(tt.args.ctx, tt.args.requestId)
			if (err != nil) != tt.wantErr {
				t.Errorf("ApprovalRequestsApiService.GetResult() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("ApprovalRequestsApiService.GetResult() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("ApprovalRequestsApiService.GetResult() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}
