/*
 * Fortanix SDKMS REST API
 *
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations.
 *
 * API version: 1.0.0-20171218
 * Contact: support@fortanix.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package sdkms

import (
	"context"
	"encoding/base64"
	"math/rand"
	"net/http"
	"strconv"
	"testing"
)

func TestSecurityObjectsApiService_AgreeKey(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body AgreeKeyRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Agree Key Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: AgreeKeyRequest{PublicKey: &TestRequisites.AgreeKey1, PrivateKey: &TestRequisites.AgreeKey2, Name: strconv.Itoa(rand.Intn(10000)), KeySize: 256, KeyType: &SECRET, Mechanism: &DiffieHellman},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.AgreeKey(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.AgreeKey() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.AgreeKey() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.AgreeKey() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSecurityObjectsApiService_DeletePrivateKey(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name            string
		fields          fields
		args            args
		want            *http.Response
		wantCheckFields []string //Name of fields from json object *http.Response to be verified.
		wantCheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr         bool
	}{
		{
			name: "Delete Private Key Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TransientValues.RSAKeyID,
			},
			want:            &http.Response{StatusCode: 204},
			wantCheckFields: []string{"StatusCode"},
			wantCheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, err := a.DeletePrivateKey(tt.args.ctx, tt.args.keyId)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.DeletePrivateKey() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.DeletePrivateKey() = %v, want %v", got, tt.want)
			}
		})
	}
}

func TestSecurityObjectsApiService_DeleteSecurityObject(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name            string
		fields          fields
		args            args
		want            *http.Response
		wantCheckFields []string //Name of fields from json object *http.Response to be verified.
		wantCheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr         bool
	}{
		{
			name: "Delete Security Object Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TransientValues.RSAKeyID,
			},
			want:            &http.Response{StatusCode: 204},
			wantCheckFields: []string{"StatusCode"},
			wantCheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, err := a.DeleteSecurityObject(tt.args.ctx, tt.args.keyId)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.DeleteSecurityObject() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.DeleteSecurityObject() = %v, want %v", got, tt.want)
			}
		})
	}
}

func TestSecurityObjectsApiService_DeriveKey(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  DeriveKeyRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	request := EncryptRequest{Alg: &AES, Mode: &CBC, Plain: base64.StdEncoding.EncodeToString([]byte(TestRequisites.Plain2)), Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))}
	mehcanism := DeriveKeyMechanism{EncryptData: &request}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Derive Key Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.AESKeyID,
				body:  DeriveKeyRequest{Name: strconv.Itoa(rand.Intn(10000)), KeySize: 128, KeyType: &AES, Mechanism: &mehcanism},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.DeriveKey(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.DeriveKey() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.DeriveKey() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.DeriveKey() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSecurityObjectsApiService_DeriveKeyEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body DeriveKeyRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	keyObject := SobjectDescriptor{Kid: TestRequisites.AESKeyID}
	request := EncryptRequest{Alg: &AES, Mode: &CBCNOPAD, Plain: base64.StdEncoding.EncodeToString([]byte(TestRequisites.Plain2)), Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))}
	mehcanism := DeriveKeyMechanism{EncryptData: &request}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Derive KeyEx Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: DeriveKeyRequestEx{Key: &keyObject, Name: strconv.Itoa(rand.Intn(10000)), KeySize: 128, KeyType: &AES, Mechanism: &mehcanism},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.DeriveKeyEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.DeriveKeyEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.DeriveKeyEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.DeriveKeyEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSecurityObjectsApiService_GenerateSecurityObject(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body SobjectRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Generate Security Object RSA - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: SobjectRequest{
					Name:    strconv.Itoa(rand.Intn(10000)),
					ObjType: &RSA,
					GroupId: TestRequisites.GroupID,
					KeySize: 2048,
				},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Generate Security Object AES - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: SobjectRequest{
					Name:    strconv.Itoa(rand.Intn(10000)),
					ObjType: &AES,
					GroupId: TestRequisites.GroupID,
					KeySize: 128,
					KeyOps:  []KeyOperations{KeyOperations_EXPORT, KeyOperations_WRAPKEY, KeyOperations_UNWRAPKEY, KeyOperations_DERIVEKEY, KeyOperations_ENCRYPT, KeyOperations_DECRYPT, KeyOperations_APPMANAGEABLE},
				},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Generate Security Object DES - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: SobjectRequest{
					Name:    strconv.Itoa(rand.Intn(10000)),
					ObjType: &DES,
					GroupId: TestRequisites.GroupID,
					KeySize: 56,
					KeyOps:  []KeyOperations{KeyOperations_EXPORT, KeyOperations_WRAPKEY, KeyOperations_UNWRAPKEY, KeyOperations_DERIVEKEY, KeyOperations_ENCRYPT, KeyOperations_DECRYPT, KeyOperations_APPMANAGEABLE},
				},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Generate Security Object DES3 - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: SobjectRequest{
					Name:    strconv.Itoa(rand.Intn(10000)),
					ObjType: &DES3,
					GroupId: TestRequisites.GroupID,
					KeySize: 168,
					KeyOps:  []KeyOperations{KeyOperations_EXPORT, KeyOperations_WRAPKEY, KeyOperations_UNWRAPKEY, KeyOperations_DERIVEKEY, KeyOperations_ENCRYPT, KeyOperations_DECRYPT, KeyOperations_APPMANAGEABLE},
				},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Generate Security Object EC - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: SobjectRequest{
					Name:          strconv.Itoa(rand.Intn(10000)),
					ObjType:       &EC,
					GroupId:       TestRequisites.GroupID,
					EllipticCurve: &NistP256,
					KeyOps:        []KeyOperations{KeyOperations_EXPORT, KeyOperations_VERIFY, KeyOperations_SIGN, KeyOperations_AGREEKEY, KeyOperations_APPMANAGEABLE},
				},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.GenerateSecurityObject(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.GenerateSecurityObject() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.GenerateSecurityObject() got = %v, want %v", got, tt.want)
			} else {
				if tt.args.body.ObjType == &RSA {
					TransientValues.RSAKeyID = got.Kid
				} else if tt.args.body.ObjType == &AES {
					TransientValues.AESKeyID = got.Kid
				} else if tt.args.body.ObjType == &DES {
					TransientValues.DESKeyID = got.Kid
				} else if tt.args.body.ObjType == &DES3 {
					TransientValues.DES3KeyID = got.Kid
				} else if tt.args.body.ObjType == &EC {
					TransientValues.ECKeyID = got.Kid
				}
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.GenerateSecurityObject() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSecurityObjectsApiService_GetSecurityObject(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Get Security Object - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.RSAKeyID,
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.GetSecurityObject(tt.args.ctx, tt.args.keyId)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.GetSecurityObject() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.GetSecurityObject() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.GetSecurityObject() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSecurityObjectsApiService_GetSecurityObjectValue(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Export Key RSA Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.RSAKeyID,
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Export Key AES Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.AESKeyID,
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Export Key DES Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.DESKeyID,
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Export Key DES3 Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.DES3KeyID,
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.GetSecurityObjectValue(tt.args.ctx, tt.args.keyId)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.GetSecurityObjectValue() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.GetSecurityObjectValue() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.GetSecurityObjectValue() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSecurityObjectsApiService_GetSecurityObjectValueEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body SobjectDescriptor
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Export KeyEx RSA Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: SobjectDescriptor{Kid: TestRequisites.RSAKeyID},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Export KeyEx AES Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: SobjectDescriptor{Kid: TestRequisites.AESKeyID},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Export KeyEx DES Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: SobjectDescriptor{Kid: TestRequisites.DESKeyID},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Export KeyEx DES3 Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: SobjectDescriptor{Kid: TestRequisites.DES3KeyID},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.GetSecurityObjectValueEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.GetSecurityObjectValueEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.GetSecurityObjectValueEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.GetSecurityObjectValueEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSecurityObjectsApiService_GetSecurityObjects(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx               context.Context
		localVarOptionals map[string]interface{}
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	params := make(map[string]interface{})
	params["groupId"] = TestRequisites.GroupID

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             []KeyObject
		wantCheckFields  []string //Name of fields from json object []KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Get All Security Objects - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:               GetContext(t),
				localVarOptionals: params,
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.GetSecurityObjects(tt.args.ctx, tt.args.localVarOptionals)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.GetSecurityObjects() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.GetSecurityObjects() got = %+v, want %+v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.GetSecurityObjects() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSecurityObjectsApiService_ImportSecurityObject(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body SobjectRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Import Key - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: SobjectRequest{
					Name:    strconv.Itoa(rand.Intn(10000)),
					Value:   "2B7E151628AED2A6ABF7158809CF4F3C",
					ObjType: &AES, GroupId: TestRequisites.GroupID,
					KeySize: 192,
				},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.ImportSecurityObject(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.ImportSecurityObject() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.ImportSecurityObject() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.ImportSecurityObject() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSecurityObjectsApiService_PersistSecurityObject(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body PersistTransientKeyRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.PersistSecurityObject(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.PersistSecurityObject() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.PersistSecurityObject() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.PersistSecurityObject() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSecurityObjectsApiService_UpdateSecurityObject(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  SobjectRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SecurityObjectsApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.UpdateSecurityObject(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SecurityObjectsApiService.UpdateSecurityObject() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SecurityObjectsApiService.UpdateSecurityObject() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SecurityObjectsApiService.UpdateSecurityObject() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}
