/*
 * Fortanix SDKMS REST API
 *
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations.
 *
 * API version: 1.0.0-20171218
 * Contact: support@fortanix.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package sdkms

import (
	"encoding/base64"
	"net/http"
	"strconv"
	"testing"
	"time"

	"golang.org/x/net/context"
)

func TestWrappingAndUnwrappingApiService_UnwrapKey(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  UnwrapKeyRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "UnwrapKey Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.AESKeyID,
				body:  UnwrapKeyRequest{Name: strconv.FormatInt(time.Now().UTC().UnixNano(), 10), WrappedKey: TransientValues.WrappedKey, ObjType: &RSA, Alg: &AES, Mode: &CBC, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &WrappingAndUnwrappingApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.UnwrapKey(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("WrappingAndUnwrappingApiService.UnwrapKey() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("WrappingAndUnwrappingApiService.UnwrapKey() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("WrappingAndUnwrappingApiService.UnwrapKey() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestWrappingAndUnwrappingApiService_UnwrapKeyEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body UnwrapKeyRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	AESKey := SobjectDescriptor{Kid: TestRequisites.AESKeyID}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             KeyObject
		wantCheckFields  []string //Name of fields from json object KeyObject to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "UnwrapKeyEx Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: UnwrapKeyRequestEx{Key: &AESKey, Name: strconv.FormatInt(time.Now().UTC().UnixNano(), 10), WrappedKey: TransientValues.WrappedKey, ObjType: &RSA, Alg: &AES, Mode: &CBC, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))},
			},
			wantCheckFields:  []string{"Name", "AcctId", "Creator", "ObjType", "Origin", "Enabled", "CreatedAt", "LastusedAt", "NeverExportable"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 201},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &WrappingAndUnwrappingApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.UnwrapKeyEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("WrappingAndUnwrappingApiService.UnwrapKeyEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("WrappingAndUnwrappingApiService.UnwrapKeyEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("WrappingAndUnwrappingApiService.UnwrapKeyEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestWrappingAndUnwrappingApiService_WrapKey(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  WrapKeyRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             WrapKeyResponse
		wantCheckFields  []string //Name of fields from json object WrapKeyResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "WrapKey Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.AESKeyID,
				body:  WrapKeyRequest{Alg: &AES, Mode: &CBC, Kid: TestRequisites.RSAKeyID, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))},
			},
			wantCheckFields:  []string{"WrappedKey"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &WrappingAndUnwrappingApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.WrapKey(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("WrappingAndUnwrappingApiService.WrapKey() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("WrappingAndUnwrappingApiService.WrapKey() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("WrappingAndUnwrappingApiService.WrapKey() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestWrappingAndUnwrappingApiService_WrapKeyEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body WrapKeyRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	AESKey := SobjectDescriptor{Kid: TestRequisites.AESKeyID}
	RSAKey := SobjectDescriptor{Kid: TestRequisites.RSAKeyID}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             WrapKeyResponse
		wantCheckFields  []string //Name of fields from json object WrapKeyResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "WrapKeyEx Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: WrapKeyRequestEx{Key: &AESKey, Subject: &RSAKey, Alg: &AES, Mode: &CBC, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))},
			},
			wantCheckFields:  []string{"WrappedKey"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &WrappingAndUnwrappingApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.WrapKeyEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("WrappingAndUnwrappingApiService.WrapKeyEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("WrappingAndUnwrappingApiService.WrapKeyEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("WrappingAndUnwrappingApiService.WrapKeyEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}
